@@ -14,4 +14,5 @@ cat foo_50 | curl -N -X PUT http://localhost:$PORT/data --data-binary @- \
   -H 'Transfer-Encoding: chunked' --max-time 10
 
 kill $PID
-wc data
+echo ''
+wc -m data
